@@ -5,7 +5,9 @@
 let observer;
 document.addEventListener("DOMContentLoaded", () => {
   const explainer = document.querySelector("[data-i18n=cancel_he_blocking_explainer]");
-  observer = new MutationObserver(() => {replaceLink(explainer)});
+  observer = new MutationObserver(() => {
+    replaceLink(explainer)
+  });
   if (explainer.innerText.length > 0) {
     replaceLink(explainer);
   } else {
@@ -14,7 +16,7 @@ document.addEventListener("DOMContentLoaded", () => {
   displayURL();
 });
 
-function replaceLink(explainer){
+function replaceLink(explainer) {
   observer.disconnect();
   const linkText = chrome.i18n.getMessage("cancel_he_blocking_network");
   const link = document.createElement("a");
@@ -26,15 +28,20 @@ function replaceLink(explainer){
 function displayURL() {
   const cancelURL = new URL(window.location.href);
   const originURL = decodeURI(cancelURL.searchParams.get('originURL'));
-  const originURLLink = document.getElementById('originURL');
-  originURLLink.innerText = originURL;
+  const originURLLink = document.getElementById('url-value');
+  const openURLButton = document.getElementById('open-url-button');
 
-  originURLLink.addEventListener("click", function() {
+  originURLLink.innerHTML = originURL;
+  originURLLink.href = originURL;
+
+  openURLButton.addEventListener("click", function() {
     if (confirm(chrome.i18n.getMessage("chrome_disable_on_this_site") + '?')) {
       const url = new URL(originURL);
       sendMessage("disable_on_site", url.host, () => {
         window.location = originURL;
       });
     }
+
+    return false;
   });
 }
